Package: GOSemSim
Type: Package
Title: GO-terms Semantic Similarity Measures
Version: 2.39.2
Authors@R: c( person(given = "Guangchuang", family = "Yu",             email = "guangchuangyu@gmail.com", role  = c("aut", "cre")),
              person(given = "Alexey",      family = "Stukalov",       email = "astukalov@gmail.com",     role  = "ctb"),
              person(given= "Pingfan",      family = "Guo",            email = "1178431277@qq.com",       role  = "ctb"),
              person(given = "Chuanle",     family = "Xiao",           email = "xiaochuanle@126.com",     role  = "ctb"),
              person(given = "Lluís",       family = "Revilla Sancho", email = "lluis.revilla@gmail.com", role  = "ctb")
             )
Maintainer: Guangchuang Yu <guangchuangyu@gmail.com>
Description: Semantic similarity analysis of Gene Ontology (GO)
        annotations provides a quantitative framework for comparing GO
        terms, gene products, and gene clusters. GOSemSim implements
        widely used information content- and graph-based similarity
        measures, including the methods of Resnik, Schlicker, Jiang,
        Lin, Wang and TCSS. It also provides utilities for preparing
        annotation data and combining term-level similarities into
        gene- and cluster-level scores.
Depends: R (>= 4.2.0)
LinkingTo: Rcpp
Imports: AnnotationDbi, DBI, digest, GO.db, methods, rlang, stats,
        utils, yulab.utils (>= 0.2.3)
Suggests: AnnotationHub, BiocParallel, BiocManager, clusterProfiler,
        DOSE, knitr, org.Hs.eg.db, quarto, readr, testthat, tidyr,
        tidyselect, ROCR
VignetteBuilder: quarto
ByteCompile: true
License: Artistic-2.0
Encoding: UTF-8
URL: https://yulab-smu.top/biomedical-knowledge-mining-book/
BugReports: https://github.com/YuLab-SMU/GOSemSim/issues
Packaged: 2026-06-29 14:19:00 UTC; root
biocViews: Annotation, GO, Clustering, Pathways, Network, Software
Roxygen: list(markdown = TRUE)
Config/roxygen2/version: 8.0.0
Config/pak/sysreqs: cmake make libpng-dev libuv1-dev libssl-dev
        zlib1g-dev
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-06-29 09:06:57 UTC
RemoteUrl: https://github.com/bioc/GOSemSim
RemoteRef: HEAD
RemoteSha: e6caf6daa62ff2442ced58e127a2a0b3d84ea33e
NeedsCompilation: yes
Author: Guangchuang Yu [aut, cre],
  Alexey Stukalov [ctb],
  Pingfan Guo [ctb],
  Chuanle Xiao [ctb],
  Lluís Revilla Sancho [ctb]
Built: R 4.6.1; aarch64-apple-darwin23; 2026-06-29 14:21:54 UTC; unix
