# Generated by roxygen2: do not edit by hand

export(buildGOmap)
export(clusterSim)
export(combineScores)
export(geneSim)
export(get_organism)
export(goSim)
export(godata)
export(load_OrgDb)
export(mclusterSim)
export(mgeneSim)
export(mgoSim)
export(parse_gff)
export(read.blast2go)
export(read.gaf)
export(set_auto_update)
export(tcss_cutoff)
export(termSim)
export(wangMethod_internal)
exportClasses(GOSemSimDATA)
importClassesFrom(AnnotationDbi,AnnotationDb)
importFrom(AnnotationDbi,columns)
importFrom(AnnotationDbi,loadDb)
importFrom(AnnotationDbi,toTable)
importFrom(DBI,dbReadTable)
importFrom(GO.db,GO.db)
importFrom(GO.db,GOBPANCESTOR)
importFrom(GO.db,GOBPOFFSPRING)
importFrom(GO.db,GOBPPARENTS)
importFrom(GO.db,GOCCANCESTOR)
importFrom(GO.db,GOCCOFFSPRING)
importFrom(GO.db,GOCCPARENTS)
importFrom(GO.db,GOMFANCESTOR)
importFrom(GO.db,GOMFOFFSPRING)
importFrom(GO.db,GOMFPARENTS)
importFrom(GO.db,GOTERM)
importFrom(digest,digest)
importFrom(methods,new)
importFrom(methods,setClass)
importFrom(methods,setMethod)
importFrom(methods,setRefClass)
importFrom(methods,slot)
importFrom(rlang,check_installed)
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(utils,read.delim)
importFrom(utils,setTxtProgressBar)
importFrom(utils,stack)
importFrom(utils,txtProgressBar)
importFrom(yulab.utils,download_yulab_file)
importFrom(yulab.utils,load_OrgDb)
importFrom(yulab.utils,ls2df)
importFrom(yulab.utils,user_dir)
importFrom(yulab.utils,yulab_msg)
importMethodsFrom(AnnotationDbi,as.list)
importMethodsFrom(AnnotationDbi,columns)
importMethodsFrom(AnnotationDbi,dbconn)
importMethodsFrom(AnnotationDbi,keys)
importMethodsFrom(AnnotationDbi,keytypes)
importMethodsFrom(AnnotationDbi,mget)
importMethodsFrom(AnnotationDbi,select)
importMethodsFrom(AnnotationDbi,toTable)
useDynLib(GOSemSim)
