# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

infoContentMethod_cpp <- function(id1_, id2_, anc_, ic_, method_, ont_) {
    .Call('_GOSemSim_infoContentMethod_cpp', PACKAGE = 'GOSemSim', id1_, id2_, anc_, ic_, method_, ont_)
}

