#' @keywords internal
"_PACKAGE"



##'Information content of GO terms
##'
##'These datasets are the information contents of GOterms.
##'
##'
##'@name go_term_table
##'@aliases GO gotbl
##'@docType data
##'@references Yu et al. (2010) GOSemSim: an R package for measuring semantic
##'similarity among GO terms and gene products \emph{Bioinformatics} (Oxford,
##'England), 26:7 976--978, April 2010. ISSN 1367-4803
##'\url{http://bioinformatics.oxfordjournals.org/cgi/content/abstract/26/7/976}
##'PMID: 20179076
##'@keywords datasets
NULL



