---
title: "GO Semantic Similarity Analysis"
author: 
- name: Guangchuang Yu
  email: guangchuangyu@gmail.com
  affiliation: Department of Bioinformatics, School of Basic Medical Sciences, Southern Medical University
date: "`r Sys.Date()`"
output:
  prettydoc::html_pretty:
    toc: true
    theme: cayman
    highlight: github
  pdf_document:
    toc: true
vignette: >
  % \VignetteIndexEntry{GOSemSim}
  % \VignetteEngine{knitr::rmarkdown}
  % \usepackage[utf8]{inputenc}
  %\VignetteEncoding{UTF-8}
---

```{r style, echo=FALSE, results="asis", message=FALSE}
knitr::opts_chunk$set(tidy = FALSE,
                      warning = FALSE,
                      message = FALSE)
```

```{r echo=FALSE, results="hide", message=FALSE}
Biocpkg <- function (pkg) {
    sprintf("[%s](http://bioconductor.org/packages/%s)", pkg, pkg)
}
```

# Vignette

Please go to <https://yulab-smu.top/biomedical-knowledge-mining-book/> for the full vignette.


# Citation


If you use `r Biocpkg('GOSemSim')` in published research, please cite the most appropriate paper(s) from this list:

1. **Yu G**. [Gene Ontology Semantic Similarity Analysis Using GOSemSim](http://dx.doi.org/10.1007/978-1-0716-0301-7_11). In: Kidder B. (eds) Stem Cell Transcriptional Networks. **_Methods in Molecular Biology_**, 2020, 2117:207-215. Humana, New York, NY. 
2. **Yu G**^#^, Li F^#^, Qin Y, Bo X^\*^, Wu Y and Wang S^\*^. [GOSemSim: an R package for measuring semantic similarity among GO terms and gene products](http://dx.doi.org/10.1093/bioinformatics/btq064). **_Bioinformatics_**. 2010, 26(7):976-978. 



# Need helps?


For questions, please post to [Bioconductor support site](https://support.bioconductor.org/) and tag your post with *GOSemSim*.

