% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/godata.R
\name{godata}
\alias{godata}
\title{godata}
\usage{
godata(
  OrgDb = NULL,
  annoDb = NULL,
  keytype = "ENTREZID",
  ont,
  computeIC = TRUE,
  processTCSS = FALSE,
  cutoff = NULL
)
}
\arguments{
\item{OrgDb}{OrgDb object (will be removed in future, please use annoDb instead)}

\item{annoDb}{GO annotation database,
can be OrgDb or a data.frame contains three columns of 'GENE', 'GO' and 'ONTOLOGY'.}

\item{keytype}{keytype}

\item{ont}{one of 'BP', 'MF', 'CC'}

\item{computeIC}{logical, whether computer IC}

\item{processTCSS}{logical, whether to prepare TCSS data. TCSS requires
\code{computeIC = TRUE}, which is enabled automatically when \code{processTCSS = TRUE}.}

\item{cutoff}{topology cutoff for TCSS subgraph construction. If \code{NULL},
empirical defaults are used; users can estimate a cutoff with \code{\link[=tcss_cutoff]{tcss_cutoff()}}.}
}
\value{
GOSemSimDATA object
}
\description{
prepare GO DATA for measuring semantic similarity
}
\author{
Guangchuang Yu
}
